starcluster.templates.sge

Package starcluster :: Package templates :: Module sge |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.templates.sge

     1  #!/usr/bin/env python
     2
     3  sgeinstall_template = """
     4  SGE_CLUSTER_NAME="starcluster"
     5  SGE_ROOT="/opt/sge6"
     6  SGE_QMASTER_PORT="63231"
     7  SGE_EXECD_PORT="63232"
     8  SGE_ENABLE_SMF="false"
     9  CELL_NAME="default"
    10  ADMIN_USER=""
    11  QMASTER_SPOOL_DIR="/opt/sge6/default/spool/qmaster"
    12  EXECD_SPOOL_DIR="/opt/sge6/default/spool"
    13  GID_RANGE="20000-20100"
    14  SPOOLING_METHOD="classic"
    15  DB_SPOOLING_SERVER="none"
    16  DB_SPOOLING_DIR="/opt/sge6/default/spooldb"
    17  PAR_EXECD_INST_COUNT="20"
    18  ADMIN_HOST_LIST="%s"
    19  SUBMIT_HOST_LIST="%s"
    20  EXEC_HOST_LIST="%s"
    21  EXECD_SPOOL_DIR_LOCAL="/opt/sge6/default/spool/exec_spool_local"
    22  HOSTNAME_RESOLVING="true"
    23  SHELL_NAME="ssh"
    24  COPY_COMMAND="scp"
    25  DEFAULT_DOMAIN="none"
    26  ADMIN_MAIL="none@none.edu"
    27  ADD_TO_RC="false"
    28  SET_FILE_PERMS="true"
    29  RESCHEDULE_JOBS="wait"
    30  SCHEDD_CONF="1"
    31  SHADOW_HOST=""
    32  EXEC_HOST_LIST_RM=""
    33  REMOVE_RC="true"
    34  WINDOWS_SUPPORT="false"
    35  WIN_ADMIN_NAME="Administrator"
    36  WIN_DOMAIN_ACCESS="false"
    37  CSP_RECREATE="false"
    38  CSP_COPY_CERTS="false"
    39  CSP_COUNTRY_CODE="US"
    40  CSP_STATE="MA"
    41  CSP_LOCATION="BOSTON"
    42  CSP_ORGA="MIT"
    43  CSP_ORGA_UNIT="OEIT"
    44  CSP_MAIL_ADDRESS="none@none.edu"
    45  """
    46
    47  sge_pe_template = """
    48  pe_name           %s
    49  slots             %s
    50  user_lists        NONE
    51  xuser_lists       NONE
    52  start_proc_args   /bin/true
    53  stop_proc_args    /bin/true
    54  allocation_rule   $round_robin
    55  control_slaves    TRUE
    56  job_is_first_task FALSE
    57  urgency_slots     min
    58  accounting_summary FALSE
    59  """
    60
    61  sgeprofile_template = """
    62  export SGE_ROOT="/opt/sge6"
    63  export SGE_CELL="default"
    64  export SGE_CLUSTER_NAME="starcluster"
    65  export SGE_QMASTER_PORT="63231"
    66  export SGE_EXECD_PORT="63232"
    67  export MANTYPE="man"
    68  export MANPATH="$MANPATH:$SGE_ROOT/man"
    69  export PATH="$PATH:$SGE_ROOT/bin/%(arch)s"
    70  export ROOTPATH="$ROOTPATH:$SGE_ROOT/bin/%(arch)s"
    71  export LDPATH="$LDPATH:$SGE_ROOT/lib/%(arch)s"
    72  """
    73